/*    
       This software may be used and distributed according to the terms of
       the GNU General Public License (GPL), incorporated herein by
       reference.  Drivers based on this skeleton fall under the GPL and
       must retain the authorship (implicit copyright) notice.
 
       This program is distributed in the hope that it will be useful, but
       WITHOUT ANY WARRANTY; without even the implied warranty of
       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
       General Public License for more details.
 */
package cricketdaemon.beaconstat;

import cricketdaemon.Util;
import cricketdaemon.module.*;
import cricketdaemon.reader.Beacon;
import java.util.*;

/**
 * The data type that is passed to higher layer module that registers a
 * callback with the BeaconStat module.
 *
 * @author Allen Miu
 */
public class BeaconStatData extends Data
{
    private static final int MAX_SEQNUM = 65536;
    private static int globalSeqNum = 0;
    public int seqNum;
    public ArrayList values;

    public BeaconDistStat latestStat;
    
    public BeaconStatData(Beacon b, ArrayList v, BeaconDistStat bds)
    {
	super(b);
	seqNum = globalSeqNum;
	globalSeqNum++;             // ensures unique sequence number
	globalSeqNum %= MAX_SEQNUM; // wrap around
	//timeStamp = curTime;
	values = v;
	latestStat = bds;
	Util.assert_nonjava(v.size() > 0, "BeaconStatData::BeaconStatData()");
    }

    public interface BeaconStatDataHandler {
	public void processBeaconStatData(BeaconStatData newData, 
					  BitSet fieldMask);
    }

    public void process(Object handler, BitSet fieldMask) 
    {
	Util.assert_nonjava(handler instanceof BeaconStatDataHandler,
		    "BeaconStatData::process() incorrect handler type");
	BeaconStatDataHandler h = (BeaconStatDataHandler) handler;
	h.processBeaconStatData(this, fieldMask);
    }
    
    public String toString()
    {
	String result = seqNum+" "+timeStamp;

	if(values != null ) {
	    result += " {\n";
	    for(int i = 0; i < values.size(); i++)
		result += values.get(i)+"\n";
	    result += " }\n";
	}
	return result;
    }
}
